==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ar.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "المفكرة",
    "Individual" : "فرد",
    "Group" : "مجموعة",
    "Resource" : "مصدر",
    "Room" : "غرفة",
    "Unknown" : "غير معرف",
    "Required" : "مطلوب",
    "Optional" : "اختياري",
    "Does not attend" : "لا يحضر",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "المنطقة الزمنية التي أنت فيها ({tz}) غير معروفة ، سيتم الرجوع إلى توقيت UTC",
    "Please create a calendar first." : "في البدء أنشئ تقويماً من فضلك",
    "New event" : "حدث جديد",
    "group" : "مجموعة",
    "Attendees" : "المشاركون",
    "Reminders" : "تذكيرات",
    "Repeating" : "التكرار",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "Confirmed" : "مؤكَّد",
    "Tentative" : "مبدئي",
    "Cancelled" : "ملغي",
    "Please add a title!" : "رجاءا ضِف عنوان",
    "Please select a calendar!" : "فضلاً إختر مفكرةً !",
    "Global" : "عالمي",
    "None" : "لا شيء",
    "Every day" : "كل يوم",
    "Every week" : "كل أسبوع",
    "Every month" : "كل شهر",
    "Every year" : "كل سنة",
    "never" : "بتاتاً",
    "after" : "بعد",
    "At time of event" : "عند وقت الحدث",
    "5 minutes before" : "قبل الحدث بـ 5 دقائق",
    "10 minutes before" : "قبل الحدث بـ 10 دقائق",
    "15 minutes before" : "قبل الحدث بـ 15 دقيقة",
    "30 minutes before" : "قبل الحدث بـ 30 دقيقة",
    "1 hour before" : "قبل الحدث بـ  1 ساعة",
    "2 hours before" : "قبل الحدث بـ  2 ساعتين",
    "Custom" : "مخصّص",
    "Audio" : "صوت",
    "E Mail" : "بريد إلكتروني",
    "Pop up" : "نافذة منبثقة",
    "sec" : "ثانية",
    "min" : "دقيقة",
    "hours" : "ساعات",
    "days" : "أيام",
    "week" : "إسبوع",
    "before" : "قبل",
    "start" : "بداية",
    "end" : "نهاية",
    "Editing reminders of unknown type not supported." : "النظام لا يدعم تحرير التذكيرات ذات النوع غير المعروف.",
    "Week {number} of {year}" : "الأسبوع {number} من {year}",
    "Successfully imported" : "تم الاستيراد",
    "Partially imported, 1 failure" : "استيراد جزء فقط ، فشل 1",
    "Partially imported, {n} failures" : "استيراد جزء فقط ، فشل {n}",
    "Audio alarm" : "تذكير صوتي",
    "Pop-up" : "نافذة منبثقة",
    "E-Mail" : "بريد إلكتروني",
    "{type} {time} before the event starts" : "{time} {type} قبل بدء الحدث",
    "{type} {time} before the event ends" : "{time} {type} قبل انتهاء الحدث",
    "{type} {time} after the event starts" : "{time} {type} بعد بدء الحدث",
    "{type} {time} after the event ends" : "{time} {type} بعد انتهاء الحدث",
    "{type} at the event's start" : "{type} عند بدء الحدث",
    "{type} at the event's end" : "{type} عند انتهاء الحدث",
    "{type} at {time}" : "{type} في {time}",
    "{calendar} shared by {owner}" : "شارك {owner} {calendar}",
    "Title of the Event" : "عنوان الحدث",
    "All day Event" : "حدث طيلة اليوم",
    "Delete" : "حذف ",
    "Cancel" : "إلغاء",
    "More ..." : "المزيد ...",
    "Create" : "انشئ",
    "Update" : "حدث",
    "Close" : "إغلاق",
    "Location" : "المكان",
    "Description" : "الوصف",
    "Event status" : "حال الحدث",
    "Visibility when sharing" : "نوع الظهور عند المشاركة",
    "Export" : "تصدير",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "لا يمكن للتقويم حالياً دعم ميزة asset pipeline نظراً لوجود علّة في مكوّن برمجي صاعد.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "فضلاً اتصل بمدير النظام واطلب منه تعطيل خيار \"asset-pipeline.enabled\" في الإعدادات.",
    "Day" : "يوم",
    "Week" : "أسبوع",
    "Month" : "شهر",
    "Today" : "اليوم",
    "Share Calendar" : "مشاركة المفكرة",
    "Shared" : "مشارك",
    "More" : "المزيد",
    "Edit" : "تعديل",
    "Link" : "الرابط",
    "Download" : "تحميل",
    "Share with users or groups" : "شارِك مع مستخدمين أو مجموعات",
    "can edit" : "يمكن التحرير",
    "New Calendar" : "مفكرة جديدة",
    "Name" : "الاسم",
    "New Subscription" : "اشتراك جديد",
    "Edit event" : "تعديل الحدث",
    "Delete Event" : "حذف الحدث",
    "Save Event" : "حفظ الحدث",
    "Time" : "إلى وقت",
    "Type" : "نوع",
    "Relative" : "مرتبط",
    "Absolute" : "مستقل",
    "Repeat" : "التكرار",
    "times every" : "مرة كل",
    "Add" : "اضف",
    "E-Mail address of attendee" : "البريد الإلكتروني للحاضر",
    "Please add your email address in the personal settings in order to add attendees." : "فضلاً آضف عنوان بريدك الإلكتروني في الإعدادات الشخصية للتمكن من إضافة الحاضرين.",
    "from" : "من",
    "to" : "إلى",
    "This event's repeating rule is not supported yet." : "قاعدة تكرار هذا الحدث غير مدعومة حتى الآن.",
    "Support for advanced rules will be added with subsequent updates." : "دعم القواعد المتقدمة ستتم إضافته في التحديثات التالية.",
    "Reset repeating rule" : "إعادة ضبط قاعدة التكرار",
    "Repeat every ..." : "يتكرر كل ...",
    "end repeat ..." : "ينتهي التكرار في ...",
    "times" : "مرات",
    "Import Calendars" : "استيراد تقاويم",
    "Import canceled" : "أُلغي الاستيراد",
    "Analyzing calendar" : "تحليل التقويم جارٍ",
    "The file contains objects incompatible with the selected calendar" : "يحوي الملف كائنات غير متوافقة مع التقويم المختار",
    "New calendar" : "مفكرة جديدة",
    "Import scheduled" : "الاستيراد مُجدوَل",
    "Import calendar" : "استيراد التقويم",
    "No Calendars selected for import" : "لم تختر تقويمات للاستيراد",
    "Primary CalDAV address" : "الرئيسية CalDAV عناوين",
    "iOS/OS X CalDAV address" : "لأنظمة التشغيل الماك/الآيفون CalDAV عناوين"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ar.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "المفكرة",
    "Hello," : "مرحبا %s،",
    "Individual" : "فرد",
    "Group" : "مجموعة",
    "Resource" : "مصدر",
    "Room" : "غرفة",
    "Unknown" : "غير معرف",
    "Required" : "مطلوب",
    "Optional" : "اختياري",
    "Does not attend" : "لا يحضر",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "المنطقة الزمنية التي أنت فيها ({tz}) غير معروفة ، سيتم الرجوع إلى توقيت UTC",
    "Please create a calendar first." : "في البدء أنشئ تقويماً من فضلك",
    "New event" : "حدث جديد",
    "group" : "مجموعة",
    "Details" : "تفاصيل",
    "Attendees" : "المشاركون",
    "Reminders" : "تذكيرات",
    "Repeating" : "التكرار",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "Confirmed" : "مؤكَّد",
    "Tentative" : "مبدئي",
    "Cancelled" : "ملغي",
    "Global" : "عالمي",
    "None" : "لا شيء",
    "Every day" : "كل يوم",
    "Every week" : "كل أسبوع",
    "Every month" : "كل شهر",
    "Every year" : "كل سنة",
    "never" : "بتاتاً",
    "after" : "بعد",
    "How about getting started by importing some calendars?" : "ماذا عن البدء باستيراد بعض التقاويم؟",
    "At time of event" : "عند وقت الحدث",
    "5 minutes before" : "قبل الحدث بـ 5 دقائق",
    "10 minutes before" : "قبل الحدث بـ 10 دقائق",
    "15 minutes before" : "قبل الحدث بـ 15 دقيقة",
    "30 minutes before" : "قبل الحدث بـ 30 دقيقة",
    "1 hour before" : "قبل الحدث بـ  1 ساعة",
    "2 hours before" : "قبل الحدث بـ  2 ساعتين",
    "Custom" : "مخصّص",
    "Audio" : "صوت",
    "Email" : "بريد إلكتروني",
    "Pop-up" : "نافذة منبثقة",
    "sec" : "ثانية",
    "min" : "دقيقة",
    "hours" : "ساعات",
    "days" : "أيام",
    "week" : "إسبوع",
    "before" : "قبل",
    "start" : "بداية",
    "end" : "نهاية",
    "Editing reminders of unknown type not supported." : "النظام لا يدعم تحرير التذكيرات ذات النوع غير المعروف.",
    "Week {number} of {year}" : "الأسبوع {number} من {year}",
    "Successfully imported" : "تم الاستيراد",
    "Partially imported, 1 failure" : "استيراد جزء فقط ، فشل 1",
    "Partially imported, {n} failures" : "استيراد جزء فقط ، فشل {n}",
    "Audio alarm" : "تذكير صوتي",
    "{type} {time} before the event starts" : "{time} {type} قبل بدء الحدث",
    "{type} {time} before the event ends" : "{time} {type} قبل انتهاء الحدث",
    "{type} {time} after the event starts" : "{time} {type} بعد بدء الحدث",
    "{type} {time} after the event ends" : "{time} {type} بعد انتهاء الحدث",
    "{type} at the event's start" : "{type} عند بدء الحدث",
    "{type} at the event's end" : "{type} عند انتهاء الحدث",
    "{type} at {time}" : "{type} في {time}",
    "{calendar} shared by {owner}" : "شارك {owner} {calendar}",
    "Title of the Event" : "عنوان الحدث",
    "All day Event" : "حدث طيلة اليوم",
    "Delete" : "حذف ",
    "Cancel" : "إلغاء",
    "More ..." : "المزيد ...",
    "Create" : "انشئ",
    "Update" : "حدث",
    "Close" : "إغلاق",
    "Location" : "المكان",
    "Description" : "الوصف",
    "Event status" : "حال الحدث",
    "Visibility when sharing" : "نوع الظهور عند المشاركة",
    "Export" : "تصدير",
    "Day" : "يوم",
    "Week" : "أسبوع",
    "Month" : "شهر",
    "Today" : "اليوم",
    "Share Calendar" : "مشاركة المفكرة",
    "Shared" : "مشارك",
    "More" : "المزيد",
    "Edit" : "تعديل",
    "Link" : "الرابط",
    "Download" : "تحميل",
    "Share with users or groups" : "شارِك مع مستخدمين أو مجموعات",
    "can edit" : "يمكن التحرير",
    "New Calendar" : "مفكرة جديدة",
    "Name" : "الاسم",
    "New Subscription" : "اشتراك جديد",
    "Edit event" : "تعديل الحدث",
    "Delete Event" : "حذف الحدث",
    "Save Event" : "حفظ الحدث",
    "Time" : "إلى وقت",
    "Type" : "نوع",
    "Relative" : "مرتبط",
    "Absolute" : "مستقل",
    "Repeat" : "التكرار",
    "times every" : "مرة كل",
    "Add" : "اضف",
    "Please add your email address in the personal settings in order to add attendees." : "فضلاً آضف عنوان بريدك الإلكتروني في الإعدادات الشخصية للتمكن من إضافة الحاضرين.",
    "from" : "من",
    "to" : "إلى",
    "This event's repeating rule is not supported yet." : "قاعدة تكرار هذا الحدث غير مدعومة حتى الآن.",
    "Support for advanced rules will be added with subsequent updates." : "دعم القواعد المتقدمة ستتم إضافته في التحديثات التالية.",
    "Reset repeating rule" : "إعادة ضبط قاعدة التكرار",
    "Repeat every ..." : "يتكرر كل ...",
    "end repeat ..." : "ينتهي التكرار في ...",
    "times" : "مرات",
    "Import Calendars" : "استيراد تقاويم",
    "Import canceled" : "أُلغي الاستيراد",
    "Analyzing calendar" : "تحليل التقويم جارٍ",
    "The file contains objects incompatible with the selected calendar" : "يحوي الملف كائنات غير متوافقة مع التقويم المختار",
    "New calendar" : "مفكرة جديدة",
    "Import scheduled" : "الاستيراد مُجدوَل",
    "Import calendar" : "استيراد التقويم",
    "No Calendars selected for import" : "لم تختر تقويمات للاستيراد",
    "Primary CalDAV address" : "الرئيسية CalDAV عناوين",
    "iOS/OS X CalDAV address" : "لأنظمة التشغيل الماك/الآيفون CalDAV عناوين"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
